#include <MoleGraph.h>
#include <OneWire.h> // Get 1-wire Library here: http://www.pjrc.com/teensy/td_libs_OneWire.html
#include <DallasTemperature.h> //Get DallasTemperature Library here:  http://milesburton.com/Main_Page?title=Dallas_Temperature_Control_Library

#define ONE_WIRE_BUS_PIN 3
#define ROUNDING 10 // decimal places in result - 10 >> 0.1, 100 >> 0.01

unsigned counter =  0;
long     previousTimer1 = 0;   //for DS18B20 reading
long     intervalTimer1 = 200;  //for DS18B20 reading - 5 Hz >> 200 ms
boolean  IsRunning = false;

float tempC1;
//float tempC2;

MoleGraph moleGraph;

// Setup a oneWire instance to communicate with any OneWire devices
OneWire oneWire(ONE_WIRE_BUS_PIN);
// Pass our oneWire reference to Dallas Temperature.
DallasTemperature sensors(&oneWire);
// Assign the addresses of your 1-Wire temp sensors.
// See the tutorial on how to obtain these addresses:
// http://www.hacktronics.com/Tutorials/arduino-1-wire-address-finder.html
// arrays to hold device address (if only one thermometer present)
DeviceAddress insideThermometer;
// arrays to hold device address (if more thermometers present - each has device address)
//DeviceAddress Probe01 = { 0x28, 0xFF, 0xD3, 0xDB, 0x61, 0x16, 0x04, 0xE4 }; //tato adresa bude ve vašem případě jiná (viz komentar vyse, kod je primo v adresari s projekty "DS18B20-hledac_adres-one_wire_address_finder.ino")
//DeviceAddress Probe02 = { 0x28, 0xFF, 0x37, 0x3C, 0x62, 0x16, 0x03, 0x89 }; //tato adresa bude ve vašem případě jiná

void UpdateGraphChannels(void)
{
  moleGraph.SetChannelValue(1, tempC1/ROUNDING);
  //moleGraph.SetChannelValue(2, tempC2/ROUNDING);
}
void MeasurementStartedCallback(void)
{
  IsRunning = true;
  previousTimer1 = 0;
  // get actual temp
  getAtctualTemp();  
  digitalWrite(13, HIGH);
}
void MeasurementStoppedCallback(void)
{
  IsRunning = false;
  previousTimer1 = 0;
  digitalWrite(13, LOW);
}
void MeasurementPausedCallback(void)
{
  IsRunning = false;
  previousTimer1 = 0;
  digitalWrite(13, LOW);
}
void MeasurementContinuedCallback(void)
{
  IsRunning = true;
  previousTimer1 = 0;
  // get actual temp
  getAtctualTemp();  
  digitalWrite(13, HIGH);
}


void setup()
{
  moleGraph.Setup();
  moleGraph.SetSendingCallback(&UpdateGraphChannels);
  moleGraph.SetMeasurementStartedCallback(&MeasurementStartedCallback);
  moleGraph.SetMeasurementStoppedCallback(&MeasurementStoppedCallback);
  moleGraph.SetMeasurementPausedCallback(&MeasurementPausedCallback);
  moleGraph.SetMeasurementContinuedCallback(&MeasurementContinuedCallback);
  pinMode(13, OUTPUT);

  // Initialize the Temperature measurement library
  sensors.begin();
  sensors.getDeviceCount();
  sensors.getAddress(insideThermometer, 0);
  // set the resolution to 10 bit (Can be 9 to 12 bits .. lower is faster)
  sensors.setResolution(insideThermometer, 12);
  //sensors.setResolution(Probe02, 10);
  // get actual temp
  getAtctualTemp();  
}

void loop()
{
  //run my timers
  unsigned long currentTimer1 = millis();
  
  moleGraph.CheckInput();
  
  //actual temp from sensor
  if((currentTimer1 - previousTimer1 > intervalTimer1) && (IsRunning == true)) {      
    // Command all devices on bus to read temperature  
    getAtctualTemp();
    previousTimer1 = currentTimer1;
  }
}

void getAtctualTemp()
{
  // get actual temp and round it
  sensors.requestTemperatures();
  tempC1 = round(sensors.getTempC(insideThermometer)*ROUNDING);
  //tempC2 = round(sensors.getTempC(Probe02)*ROUNDING);  
}


